# Generated by Django 2.2.24 on 2022-02-08 12:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('xprez', '0014_remove_content_margin_top'),
    ]

    operations = [
        migrations.AddField(
            model_name='ckeditor',
            name='content_centered',
            field=models.BooleanField(default=False),
        ),
    ]
