# Generated by Django 2.0.1 on 2018-01-15 12:06

from django.db import migrations, models
import xprez.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ('xprez', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='attachment',
            name='file',
            field=models.FileField(upload_to='files'),
        ),
        migrations.AlterField(
            model_name='codetemplate',
            name='template_name',
            field=xprez.models.fields.TemplatePathField(blank=True, max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='content',
            name='changed',
            field=models.DateTimeField(auto_now=True, db_index=True, verbose_name='changed'),
        ),
        migrations.AlterField(
            model_name='content',
            name='created',
            field=models.DateTimeField(auto_now_add=True, db_index=True, verbose_name='created'),
        ),
        migrations.AlterField(
            model_name='gallery',
            name='width',
            field=models.CharField(choices=[('full', 'full'), ('mid', 'mid'), ('text', 'text')], default='full', max_length=50),
        ),
        migrations.AlterField(
            model_name='mediumeditor',
            name='width',
            field=models.CharField(choices=[('full', 'full'), ('mid', 'mid'), ('text', 'text')], default='full', max_length=50),
        ),
        migrations.AlterField(
            model_name='photo',
            name='image',
            field=models.ImageField(upload_to='photos'),
        ),
        migrations.AlterField(
            model_name='quote',
            name='image',
            field=models.ImageField(blank=True, null=True, upload_to='quotes'),
        ),
        migrations.AlterField(
            model_name='video',
            name='poster_image',
            field=models.ImageField(blank=True, null=True, upload_to='video'),
        ),
        migrations.AlterField(
            model_name='video',
            name='video_type',
            field=models.CharField(choices=[('youtube', 'YouTube'), ('vimeo', 'Vimeo')], max_length=50),
        ),
        migrations.AlterField(
            model_name='video',
            name='width',
            field=models.CharField(choices=[('full', 'full'), ('mid', 'mid'), ('text', 'text')], default='full', max_length=50),
        ),
    ]
