# Generated by Django 2.2.9 on 2020-01-29 10:59

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('xprez', '0007_auto_20191221_1522'),
        ('xprez', '0007_auto_20191227_2150'),
    ]

    operations = [
    ]
