# Generated by Django 2.2.24 on 2022-03-12 17:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('xprez', '0017_auto_20220208_1401'),
    ]

    operations = [
        migrations.AlterField(
            model_name='attachment',
            name='file',
            field=models.FileField(max_length=300, upload_to='files'),
        ),
    ]
