# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-04-15 13:36
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('xprez', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='CodeSnippet',
            fields=[
                ('content_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='xprez.Content')),
                ('title', models.CharField(blank=True, max_length=150, null=True)),
                ('code', models.TextField()),
                ('lang', models.CharField(choices=[(b'python', b'Python'), (b'js', b'JavaScript'), (b'django_template', b'Django Template'), (b'php', b'PHP'), (b'xml', b'XML')], default=b'python', max_length=20, verbose_name=b'Jazyk')),
            ],
            bases=('xprez.content',),
        ),
    ]
