# Generated by Django 2.2.24 on 2022-02-08 12:55

from django.db import migrations


def migrate_ckeditor_width(apps, schema_editor):
    """
    When not boxed, force width to "Text width"
    """

    CkEditor = apps.get_model('xprez.CkEditor')
    CkEditor.objects.filter(box=False).update(width='text')


def noop(*args, **kwargs):
    pass


class Migration(migrations.Migration):

    dependencies = [
        ('xprez', '0015_ckeditor_content_centered'),
    ]

    operations = [
        migrations.RunPython(migrate_ckeditor_width, noop)
    ]
